********
Glossary
********

.. glossary::

    Devpi
        A powerful :term:`PyPI`-compatible server and a complimentary command
        line tool to drive packaging, testing and release activities with
        :term:`Python`.

        .. seealso::

            * `Official devpi documentation <http://doc.devpi.net/>`__

    Pip
        A recommended tool for installing :term:`Python` packages.

        .. seealso:: https://pip.pypa.io

    Python
        A programming language that lets you work quickly and integrate systems
        more effectively.

        .. seealso:: https://www.python.org/

    Pypi
        The Python Package Index (PyPI) is a repository of software for the
        Python programming language.

        .. seealso:: https://pypi.org/

    Virtualenv
        A tool to create isolated Python environments.

        .. seealso:: https://virtualenv.pypa.io/en/latest/

    Wiz
        Package manager to run command in reliable environment.

        .. seealso:: :ref:`wiz:main`
